Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src\agents_sdk_models\__init__.py | 13 | 0 | 0 | 100%
src\agents_sdk_models\anthropic.py | 24 | 5 | 0 | 79%
src\agents_sdk_models\clearify_pipeline.py | 117 | 12 | 0 | 90%
src\agents_sdk_models\context.py | 112 | 4 | 0 | 96%
src\agents_sdk_models\flow.py | 212 | 43 | 0 | 80%
src\agents_sdk_models\gemini.py | 20 | 4 | 0 | 80%
src\agents_sdk_models\gen_agent.py | 70 | 1 | 0 | 99%
src\agents_sdk_models\llm.py | 101 | 7 | 0 | 93%
src\agents_sdk_models\message.py | 16 | 4 | 0 | 75%
src\agents_sdk_models\ollama.py | 20 | 3 | 0 | 85%
src\agents_sdk_models\pipeline.py | 147 | 11 | 0 | 93%
src\agents_sdk_models\step.py | 150 | 30 | 0 | 80%
src\agents_sdk_models\tracing.py | 71 | 20 | 0 | 72%
Total | 1073 | 144 | 0 | 87%

No items found using the specified filter.